
##Written by Sam Yeaman
##Used for plotting the alkaloid concentrations along with the PCA plots shown in Figure 6 and Figure S15


alk <- read.table ("~/Dropbox/desktop/for_sukyi/quant_varieties_jill_data_april_30_2018.txt",T)

alk$chemotype <- gsub ("ROX","PS7",alk$chemotype)

nam_ord <- c ("L","P","T","11","40","M","PS1","PS4","PS7","BC")
alk_type <- factor (alk$chemotype, levels = nam_ord)

par (mfcol = c (2,3))

 
 par (mar = c (4,5,3,1))
 stripchart(alk$noscapine/1000 ~ alk_type, vertical = T, pch = 1,ylab = "", xlab = "", ylim = c (0,7),xlim = c (1,10), col = "white",cex.lab = 1.5, xaxt = "n",cex.axis = 1.5)
polygon (c(-1,5.5,5.5,-1),c(1000000,1000000,-1000,-1000),col = rgb(0.8,0.8,0.8, alpha = 0.5), border = NA)
points (as.numeric (alk_type),alk$noscapine/1000)
text (3,6.9,"Noscapine cluster",cex = 1.3)
text (3,6.4,"deleted",cex = 1.3)

text (8,6.9,"Noscapine cluster", cex = 1.3)
text (8,6.4,"present",cex = 1.3)

par (las = 3)
mtext("Noscapine concentration (umol/g)",2,padj = -3.5)
axis (1, at = 1:length(nam_ord), labels = nam_ord, cex.axis = 1.5)
par (las = 1)


 par (mar = c (6,5,1,1))

stripchart(alk$morphine/1000 ~ alk_type, vertical = T, pch = 1, ylab = "", xlab = "",cex.lab = 1.5, xaxt = "n",cex.axis = 1.5)
par (las = 3)
mtext("Morphine concentration (umol/g)",2,padj = -3.5)
axis (1, at = 1:length(nam_ord), labels = nam_ord, cex.axis = 1.5)
par (las = 1)
mtext("Cultivar",1,padj = 4.5)

 par (mar = c (4,5,3,1))
stripchart(alk$thebaine/1000 ~ alk_type, vertical = T, pch = 1, ylab = "", xlab = "",cex.lab = 1.5, xaxt = "n",cex.axis = 1.5)

par (las = 3)
mtext("Thebaine concentration (umol/g)",2,padj = -3.5)
axis (1, at = 1:length(nam_ord), labels = nam_ord, cex.axis = 1.5)
par (las = 1)


 par (mar = c (6,5,1,1))

stripchart(alk$codeine/1000 ~ alk_type, vertical = T, pch = 1, ylab = "", xlab = "",cex.lab = 1.5, xaxt = "n",cex.axis = 1.5)
par (las = 3)
mtext("Codeine concentration (umol/g)",2,padj = -3.5)
axis (1, at = 1:length(nam_ord), labels = nam_ord, cex.axis = 1.5)
par (las = 1)
mtext("Cultivar",1,padj = 4.5)




#alkaloid PCA:

ctypes <- unique (alk$chemotype)

alk_sum <- array (NA, c(length(ctypes),8))

for (qq in 1:length (ctypes)){

	int1 <- alk[alk$chemotype == ctypes[qq],]
	
	alk_sum[qq,2:8] <- colMeans (log10(int1[,3:9]+1))
	alk_sum[qq,1] <- ctypes[qq]
}

write.table (alk_sum,"temp778.txt")
alk_sum <- read.table ("temp778.txt")

alk_pca <- prcomp (alk_sum[,2:8])
alk_pca2 <- alk_pca$x
rownames (alk_pca2) <- ctypes


##CNV:

bia_cnv <- read.table ("~/Dropbox/desktop/for_sukyi/CNV_depth_raw_forPCA_BIA.csv",sep = ",",T)

nonbia_cnv <- read.table ("~/Dropbox/desktop/for_sukyi/outBIA_depth_raw_forPCA.csv",sep = ",",T)


bia_cnv_pc <- prcomp (t(bia_cnv[,2:11]))
nonbia_cnv_pc <- prcomp (t(nonbia_cnv[,2:11]))

bia_cnv_pc2 <- bia_cnv_pc$x
nonbia_cnv_pc2 <- nonbia_cnv_pc$x


#par(mfcol = c (1,2))
 par (mar = c (4,5,3,1))

plot (alk_pca2[,1], alk_pca2[,2],xlab = "PC1 Alkaloids",ylab = "PC2 Alkaloids", main = "", ylim = c (-3,3.5),xlim = c (-3.5,4),cex.lab = 1.5,cex.axis = 1.5)


adj1 <- alk_pca2[,2]+(0.12*max(alk_pca2[,2]))
adj1[7] <- 0.5
adj1[3] <- -0.7
adj1[10] <- alk_pca2[10,2]

adj2 <- alk_pca2[,1]
adj2[10] <- 1.65
adj2[1] <- -2.15
adj2[6] <- -2.95
text (adj2, adj1,alk_sum[,1],cex = 1.5)

lab1 <- colnames(bia_cnv[,2:11])
lab1 <- gsub ("X","",lab1)
rownames(bia_cnv_pc2) <- lab1
adj2 <- bia_cnv_pc2[,1]
adj1 <- bia_cnv_pc2[,2]+(0.12*max(bia_cnv_pc2[,2]))
adj1[9] <- 0
adj1[8] <- bia_cnv_pc2[8,2]
adj2[8] <- 4.8
 par (mar = c (6,5,1,1))

plot (bia_cnv_pc2[,1], bia_cnv_pc2[,2],xlab = "PC1 BIA CNVs",ylab = "PC2 BIA CNVs", main = "",ylim = c (-6.5,6),xlim = c (-10,10),cex.lab = 1.5,cex.axis = 1.5)
text (adj2, adj1,lab1, cex = 1.5)




#######END FIGURE####
#######END FIGURE####
#######END FIGURE####
#######END FIGURE####
#######END FIGURE####
#######END FIGURE####
#######END FIGURE####
#######END FIGURE####

quartz() #cnv_non_bia_genes.pdf
lab1 <- colnames(nonbia_cnv[,2:11])
lab1 <- gsub ("X","",lab1)
rownames(nonbia_cnv_pc2) <- lab1
plot (nonbia_cnv_pc2[,1], nonbia_cnv_pc2[,2],xlab = "PC1",ylab = "PC2", main = "",ylim = c (-120,120))
adj1 <- nonbia_cnv_pc2[,2]+(0.05*max(nonbia_cnv_pc2[,2]))
adj1[4] <- -40
text (nonbia_cnv_pc2[,1], adj1,lab1)



#get the percent variance explained:
load_alk <- alk_pca$sdev^2 / sum(alk_pca$sdev^2)
load_bia <- bia_cnv_pc$sdev^2 / sum(bia_cnv_pc$sdev^2)
load_nonbia <- nonbia_cnv_pc$sdev^2 / sum(nonbia_cnv_pc$sdev^2)


the_vars <- alk_sum[,1]

dist_mat <- array (NA,c(length(the_vars)^2,5))
mat_bia <- array (NA, c (length(the_vars),length(the_vars)))
mat_nonbia <- array (NA, c (length(the_vars),length(the_vars)))
mat_alk <- array (NA, c (length(the_vars),length(the_vars)))

count <- 1
for (i in 1:length(the_vars)){
for (j in 1:length(the_vars)){
	
	if (i > j){
	
		dist_mat[count,1] <- the_vars[i]	
		dist_mat[count,2] <- the_vars[j]	

		ind1 <- which (rownames(alk_pca2) == the_vars[i])
		ind2 <- which (rownames(alk_pca2) == the_vars[j])
		
		dist_mat[count,3] <- sum ((alk_pca2 [ind1,] - alk_pca2[ind2,])^2 * load_alk)
		mat_alk [i,j] <- sum ((alk_pca2 [ind1,] - alk_pca2[ind2,])^2 * load_alk)

		
		ind1 <- which (rownames(bia_cnv_pc2) == the_vars[i])
		ind2 <- which (rownames(bia_cnv_pc2) == the_vars[j])

		dist_mat[count,4] <- sum ((bia_cnv_pc2 [ind1,] - bia_cnv_pc2[ind2,])^2 * load_bia)
		mat_bia [i,j] <- sum ((bia_cnv_pc2 [ind1,] - bia_cnv_pc2[ind2,])^2 * load_bia)


		ind1 <- which (rownames(nonbia_cnv_pc2) == the_vars[i])
		ind2 <- which (rownames(nonbia_cnv_pc2) == the_vars[j])

		dist_mat[count,5] <- sum ((nonbia_cnv_pc2 [ind1,] - nonbia_cnv_pc2[ind2,])^2 * load_nonbia)
		mat_nonbia [i,j] <- sum ((nonbia_cnv_pc2 [ind1,] - nonbia_cnv_pc2[ind2,])^2 * load_nonbia)

		count <- count + 1		
	}
	
	

}
}

dist_mat <- dist_mat[is.na(dist_mat[,1]) == F,]

write.table (dist_mat,"temp456.txt")
dist_mat <- read.table ("temp456.txt")


library (vegan)

mantel(mat_alk,mat_bia)

mantel(mat_nonbia,mat_bia)

mantel(mat_alk,mat_nonbia)


