## Figure S17 - Repeat landscapes of enriched transposons.
# Script by Sonja Dunemann

# Set directory and load library
library("tidyverse")

# Load data
distances <- read.table("PGA_assembly_fix_inversions_shortheaders.fasta.families.summary", 
                        sep = ' ', header = T, stringsAsFactors = F, check.names=FALSE)   

distances_long <- gather(distances,"class","bp",2:41) %>% 
  filter(class != "X") %>% 
  mutate (perc=bp/2713090712*100)
                  
distances_long_by_class <- distances_long %>% group_by(class) 


# Filter the enriched TEs
selected_classes <- c("DNA/hAT-Tag1", "LINE/L1", "SINE?", "LTR/Gypsy", "LINE/RTE-BovB", "RC/Helitron", "LINE/L1-Tx1","LTR","DNA/MuLE-MuDR")

selected <- distances_long_by_class %>%
  filter(class %in% selected_classes)


# Plot enriched TEs
ggplot(data = selected, aes(x=Div,y=perc) ) +
  geom_col() +
  facet_wrap(~ class, scales = "free_y",ncol=3)+
  theme_minimal() +
  ylab("% of Genome") +
  xlab("Kimura substitution level") +
  scale_y_continuous(labels = function(x) format(x,scientific = TRUE)) +
  ggsave("Kimura_indiv.pdf", width=20, height=10, units="cm")
