##Written by Sam Yeaman
##Takes the non-tandemly duplicated genes and calculates the proportion found in clusters at different clustering distances.
##Used to generate two of the tables in the supplementary materials showing the cluster content across different levels, used in Tables S6 & S7

options(stringsAsFactors=F)
setwd("~/Dropbox/desktop/for_sukyi")
 
input <- read.table ("~/Dropbox/desktop/for_sukyi/pathway_genes_hic_inversion_clustered_TANDEM.txt",T,sep = "\t") 

clusters <- read.table ("~/Dropbox/desktop/for_sukyi/poppy_clusters_500kb_5kwindow_new109.txt",T) 



clusters$chrom_mod <- sapply (strsplit(as.character (clusters$chrom), split = "_contig"),"[[",1)

#size of scaffolds:
int1 <- unique (clusters$chrom)
int2 <- sapply(strsplit (int1,split = "length_"),"[[",2)
max_chroms <- cbind (int1,int2)


all_cuts <- c(0.1,0.2,0.5,1,5,10,20,50,100)
the_cut_names <- paste ("clust",all_cuts,sep = "")
all_cuts <- all_cuts * 10^6


tot_chroms <- sum(as.numeric (max_chroms[,2]))

the_cuts <- all_cuts[3]
the_cuts <- the_cuts 


the_pathways <- c("sanguinarine","thebaine","reticuline","noscapine","morphine","papaverine","dopamine_4HPAA","unknown")



results_out <- array (NA, c ((length (the_pathways)),(length(the_cut_names)+1)))
results_p <- array (NA,(length(the_cut_names)+1))

for (jj in 1:length (all_cuts)){
	
	this_cut <- the_cut_names[jj]
	ind_cut <- which (colnames(input) == this_cut)	

	for (ii in 1:length (the_pathways)){
	
		this_pathway <- the_pathways[ii]
		
		sub1 <- input[(grep (this_pathway,input$pathway_new)),]

		results_out[ii,(jj+1)] <- sum (sub1[,ind_cut] > 0) /length (grep (this_pathway,input$pathway_new))
	
		results_out[ii,1] <- length (grep (this_pathway,input$pathway_new))
	
	}
	
	test1 <- rbind ((results_out[,1] * results_out[,(jj+1)]),(results_out[,1] * (1-results_out[,(jj+1)])))
	test1 <- test1[,1:(ncol(test1)-1)]
	test2 <- chisq.test(test1,simulate.p.value = T)
	
	results_p[(jj+1)] <- test2$p.value	
}

rownames(results_out) <- c(the_pathways)
colnames(results_out) <- c("num_gene",all_cuts)


results_out <- results_out[order(rownames(results_out)),]
results_out <- rbind (results_out,results_p)
rownames(results_out)[nrow(results_out)] <- "p-value"

write.table (results_out, "results_proportion_of_each_pathway_clustered.txt",row.names = T, col.names = T, quote = F, sep = "\t")



###now get the proportion of genes that are in clusters with other members of their same pathway (number of times that  "table" on the clustering numbers returns > 1


tot_chroms <- sum(as.numeric (max_chroms[,2]))


the_cuts <- all_cuts[1]
the_cuts <- the_cuts * 10^6




results_out <- array (NA, c ((length (the_pathways)),(length(the_cut_names)+1)))
results_p <- array (NA,(length(the_cut_names)+1))

for (jj in 1:length (all_cuts)){
	
	this_cut <- the_cut_names[jj]
	ind_cut <- which (colnames(input) == this_cut)	

	for (ii in 1:length (the_pathways)){
	
		this_pathway <- the_pathways[ii]
		
		sub1 <- input[(grep (this_pathway,input$pathway_new)),]
		
		sub2 <- sub1[sub1[,ind_cut] > 0,ind_cut]
		
		test_int <- table (sub2)		
		test_int2 <- test_int[test_int > 1]
		
		results_out[ii,(jj+1)] <- sum (test_int2) / length(grep (this_pathway,input$pathway_new))
	
		results_out[ii,1] <- length(grep (this_pathway,input$pathway_new))
	
	}
	
	test1 <- rbind ((results_out[,1] * results_out[,(jj+1)]),(results_out[,1] * (1-results_out[,(jj+1)])))
	test1 <- test1[,1:(ncol(test1)-1)]
	test2 <- chisq.test(test1,simulate.p.value = T)
	
	results_p[(jj+1)] <- test2$p.value	
}

rownames(results_out) <- c(the_pathways)
colnames(results_out) <- c("num_gene",all_cuts)


results_out <- results_out[order(rownames(results_out)),]
results_out <- rbind (results_out,results_p)
rownames(results_out)[nrow(results_out)] <- "p-value"

write.table (results_out, "results_proportion_of_each_pathway_clustered_same_genes.txt",row.names = T, col.names = T, quote = F, sep = "\t")



