##Script written by Sam Yeaman
##This is a rough script used to plot the chromosome-scale scaffolds and the BIA pathway genes, with various colouring schemes depending on the figure application
##Used in the poppy manuscript for Figure 2 and S3 


#####START HERE
library(RColorBrewer)
options(stringsAsFactors=F)
setwd("~/Dropbox/desktop/for_sukyi")


pseudo_in <- read.table ("~/Dropbox/desktop/for_sukyi/109-entry_pathway_gene_FIXED.list",T,sep = "\t")

pseudo <- pseudo_in[pseudo_in[,10] != "",]
pseudo$the_pos <- paste (pseudo$cScaf, pseudo$start, sep = "---")

pathway <- read.table ("~/Dropbox/desktop/for_sukyi/109-entry_pathway_gene_FIXED.list",T,sep = "\t")

ind1 <- grep ("NW",pathway$Guo_contig)
pathway$guo_comparison <- array ("yes",nrow(pathway))
pathway$guo_comparison[ind1] <- "no"

pathway <- cbind(sapply(strsplit(pathway[,1],split = ".",fixed = T),"[[",1), pathway[,2:4], pathway[,1],pathway[,11])
colnames (pathway) <- c("New.name","Chromosome","Start","Stop","path","guo_comparison")

pathway <- pathway[order(pathway$Chromosome,as.numeric(pathway$Stop)),]


genes <- pathway


#RECODE low and high values for each window (start and stop are not always low/high):
pathway$Low <- pathway$Start
ind1 <- pathway$Start > pathway$Stop
pathway$Low[ind1] <- pathway$Stop[ind1]

pathway$High <- pathway$Stop
pathway$High[ind1] <- pathway$Start[ind1]


annot1 <- read.table ("annotations_old_genome.txt", sep = "\t")

pathway$enzyme_family <- array (NA,nrow(pathway))
pathway$pathway_membership <- array (NA,nrow(pathway))

for (i in 1:nrow (pathway)){
	
	ind1 <- which (annot1[,2] == pathway$New.name[i])
	
	if (length (ind1) > 0){
		pathway$enzyme_family[i] <- annot1[ind1[1],3]	
		pathway$pathway_membership[i] <- annot1[ind1[1],4]	
	} else {
		pathway$enzyme_family[i] <- "unknown"	
		pathway$pathway_membership[i] <- "unknown"	
	}
}

contigs <- unique (pathway$Chromosome)

output <- pathway


the_cuts <- c(0.1,0.2,0.5,1,5,10,20,50,100)
the_cuts <- the_cuts * 10^6

for (qq in 1:length(the_cuts)){

all_clust <- NULL

int1 <- the_cuts[qq]

cluster_count <- 1  #clustered genes get positive numbers
non_count <- -1 ##non-clustered genes get negative numbers

lastcluster <- FALSE


for (ii in 1:length (contigs)){
	sub1 <- pathway[pathway$Chromosome == contigs[ii],]	

	if (nrow (sub1) > 1){
		
		the_cluster <- array(NA,nrow (sub1))

		the_length <- as.numeric (sapply (strsplit (sub1[1,2],split = "_length_"),"[[",2))
	
		#int1 <- the_length / 100   #set here to make it by cMs
	
		the_diffs <- abs(sub1[1:(nrow(sub1)-1),3] - sub1[2:nrow(sub1),3])
	
		smalls <- the_diffs < int1
	
		### Identify the clustered genes:
		ind1 <- which (smalls)

		clust1 <- array (NA,length (ind1))

		if (length (ind1) > 1){
			
			for (zz in 1:(length (ind1)-1)){
				if (ind1[zz] == (ind1[(zz+1)]-1)){
					clust1[zz] <- cluster_count
				} else {
					clust1[zz] <- cluster_count
					cluster_count <- cluster_count + 1
				}	
			}
			clust1[length(ind1)] <- cluster_count

			the_cluster [ind1] <- clust1
			the_cluster [ind1+1] <- clust1

			cluster_count <- cluster_count + 1
		} 
		if (length (ind1) == 1){ #if only one pair of genes is clustered
			the_cluster [ind1] <- cluster_count
			the_cluster [ind1+1] <- cluster_count
			cluster_count <- cluster_count + 1
		}
			
			
		#code any remaining NA's as non-clustered genes	
		ind2 <- which (is.na(the_cluster))
		
		if (length (ind2) > 0){  
			seq4 <- seq (non_count, (non_count - length (ind2) + 1), by = -1)
	
			the_cluster [ind2] <- seq4
	
			non_count <- min (the_cluster) - 1
		}
	
		all_clust <- c (all_clust,the_cluster)
			
	} else {
		all_clust <- c (all_clust,non_count)
		
		non_count <- non_count - 1
	}
		
}

	output <- cbind (output,all_clust)
	names(output)[ncol(output)] <- paste ("clust",(int1/10^6),sep = "")

}
output$scaffold_name <- sapply(strsplit(as.character(output$Chromosome),split = "__"),"[[",1)


int1 <- table (output$scaffold_name)

clust_count <- 1
clust_count2 <- -1

for (ii in 1:length (int1)){

	if (int1[ii] > 1){
		ind1 <- which (output$scaffold_name == names(int1[ii]))
		output$clust100[ind1] <- clust_count
		clust_count <- clust_count + 1					
	} else {
		ind1 <- which (output$scaffold_name == names(int1[ii]))
		output$clust100[ind1] <- clust_count2
		clust_count2 <- clust_count2 - 1
	}	
}


###new pathway names:
ee <- read.table ("~/Dropbox/desktop/for_sukyi/pathway_genes_new_pathway_names.txt",T,sep = "\t")

ff <- cbind (ee$pathway_membership,ee$New.name)
colnames(ff) <- c ("pathway_new","New.name")

output$ID <- paste (output$Chromosome,output$Start,sep = "---")

output$pathway_new <- array (NA,nrow(output))


for (i in 1:nrow (output)){
	
	int1 <- which (ff[,2] == output$New.name[i])
	output$pathway_new[i] <- ff[int1[1],1]
	
}




#####
#####
#####

output$scaffold_name <- sapply(strsplit(as.character(output$Chromosome),split = "__"),"[[",1)

name_to_plot <- "clust0.1"
toplot <- which (colnames(output) == name_to_plot)

name_to_scaf <- "clust100"
toscaf <- which (colnames(output) == name_to_scaf)

toplot_cluster <- unique (output[,toplot])
toplot_cluster <- toplot_cluster[toplot_cluster > 0]

output_plot1 <- output[output[,toplot] > 0,]
output_nonclust <- output[which(output[,toplot] < 0),]


tab1 <- table (output_plot1[,toplot])
ind1 <- which (tab1 >= 2) ## at least this many genes in the cluseter
nam1 <- names (tab1[ind1])

output_plot <- output_plot1[output_plot1[,toplot] %in% nam1,]


starts <- tapply (c(as.numeric (output_plot$Start),as.numeric (output_plot$Stop)), c(output_plot[,toplot],output_plot[,toplot]),min)
ends <- tapply (c(as.numeric (output_plot$Start),as.numeric (output_plot$Stop)), c(output_plot[,toplot],output_plot[,toplot]),max)


length1 <- ends - starts
length1 <- length1[order (as.numeric (length1),decreasing = T)]

tomerg <- cbind (names(length1),length1)
colnames (tomerg) <- c("clustername","length")

output_plot2 <- merge (output_plot,tomerg, by.x = name_to_plot,by.y = "clustername",all.x = T)
toplot_int <- which (colnames(output_plot2) == name_to_plot) 
output_plot2 <- cbind(output_plot2[,2:6],output_plot2[,toplot_int],output_plot2[,7:ncol(output_plot2)]) #TIDY UP
colnames (output_plot2)[6] <- name_to_plot # TIDY UP

###OTHER CHROMS
output_other_scaf <- output_nonclust[!(output_nonclust$Chromosome %in% output_plot1$Chromosome),] #get the other chromosomes that don't have clusters
output_nonclust <- output_nonclust[(output_nonclust$Chromosome %in% output_plot1$Chromosome),]

starts <- tapply (c(as.numeric (output_other_scaf$Start),as.numeric (output_other_scaf$Stop)), c(output_other_scaf[,toplot],output_other_scaf[,toplot]),min)
ends <- tapply (c(as.numeric (output_other_scaf$Start),as.numeric (output_other_scaf$Stop)), c(output_other_scaf[,toplot],output_other_scaf[,toplot]),max)

length1 <- ends - starts
length1 <- length1[order (as.numeric (length1),decreasing = T)]

tomerg <- cbind (names(length1),length1)
colnames (tomerg) <- c("clustername","length")

output_other_scaf2 <- merge (output_other_scaf,tomerg, by.x = name_to_plot,by.y = "clustername",all.x = T)
toplot_int <- which (colnames(output_other_scaf2) == name_to_plot) 
output_other_scaf2 <- cbind(output_other_scaf2[,2:6], output_other_scaf2[,toplot_int], output_other_scaf2[,7:ncol(output_plot2)]) #TIDY UP
colnames (output_other_scaf2)[6] <- name_to_plot # TIDY UP
output_other_scaf2$clust100[output_other_scaf2$clust100 == -1] <- 11

##END OTHER CHROMS


output_plot2 <- rbind(output_plot2,output_other_scaf2)

toscaf <- which (colnames(output_plot2) == name_to_scaf)


length2 <- paste (output_plot2[,toscaf],output_plot2$length, sep = "__") ### get the length of the combined clusters:
length3 <- strsplit(unique (length2),split = "__")
length4 <- cbind (sapply(length3,"[[",1),sapply(length3,"[[",2))
length5 <- tapply (as.numeric (length4[,2]),length4[,1],sum)

length5 <- length5[order (length5,decreasing = T)]


write.table (output, "pathway_genes_hic_inversion_clustered.txt",col.names = T, row.names = F, quote = F, sep = "\t")

####
####
####
#### PLOTTER
#### PLOTTER
#### PLOTTER
####
####
####

plot_cnv <- F
plot_te <- F
plot_nonpath <- F
te_all_clust <- NULL
plot_nonclust <- T

cnv_size <- 2000

ymult <- 10 #how much to inflate the y-axis
yheight <- 0.8 ## plotting height of the genes
ydisp_offset <- 2 #how much to offset the scaffolds from the chromosome
yclust_offset <- 0.3 #how big to make the boxes plotting the cluster size on the chromosome
nonpath_size <- 0.5 #how big to make the non-pathway genes
text_cex <- 0.62
the_srt <- 90
text_disp1 <- 5000 #minimum text distance
text_disp2 <- 5000 #minimum text distance
non_clust_offset <- -5000
extend_x <- 1000 	#sets how much of the chromsome is plotted beyond the extreme genes in the cluster


toplot <- which (colnames(output_plot2) == name_to_plot)


cnv_cols <- c ("black","grey50","white","red")

xlims <- c ((max(length5)*-0.1),(max(length5)*1.3))

the_chrom <- as.character (output_plot2$Chromosome)
output_plot2$chrom_length <- as.numeric (sapply (strsplit (the_chrom,split = "length_"),"[[",2))
chrom_mult <- max(as.numeric (output_plot2$chrom_length)) / xlims[2]


plotcol_choice <- "pathway_new"  
#plotcol_choice <- "enzyme_family"     
#plotcol_choice <- "guo_comparison"  



if (plotcol_choice == "pathway_new"){
	col_plot_ind <- which (colnames(output_plot2) == plotcol_choice) #set the column to be used for colour plotting

	
	col_plot <- array(9,nrow(output_plot2))
	col_plot[output_plot2[,col_plot_ind] == "morphine"] <- 1
	col_plot[output_plot2[,col_plot_ind] == "thebaine"] <- 2
	col_plot[output_plot2[,col_plot_ind] == "noscapine"] <- 3
	col_plot[output_plot2[,col_plot_ind] == "reticuline"] <- 4
	col_plot[output_plot2[,col_plot_ind] == "dopamine_4HPAA"] <- 5
	col_plot[output_plot2[,col_plot_ind] == "sanguinarine"] <- 6
	col_plot[output_plot2[,col_plot_ind] == "unknown"] <- 7
	col_plot[output_plot2[,col_plot_ind] == "papaverine"] <- 8
	col_plot[output_plot2[,col_plot_ind] == "papaverine_derivatives"] <- 8
	col_plot[output_plot2[,col_plot_ind] == "reticuline_derivatives"] <- 4
	output_plot2$col_plot <- col_plot
	the_cols <- c("cyan","purple","black",rgb(0.5,0,0),"orange","red",rgb(0,0.5,1),rgb(0.75,0.75,0.25),rgb(0,0.5,0.5)) 

	col_plot_ind <- which (colnames(output_nonclust) == plotcol_choice) #set the column to be used for colour plotting
	
	col_plot <- array(9,nrow(output_nonclust))
	col_plot[output_nonclust[,col_plot_ind] == "morphine"] <- 1
	col_plot[output_nonclust[,col_plot_ind] == "thebaine"] <- 2
	col_plot[output_nonclust[,col_plot_ind] == "noscapine"] <- 3
	col_plot[output_nonclust[,col_plot_ind] == "reticuline"] <- 4
	col_plot[output_nonclust[,col_plot_ind] == "dopamine_4HPAA"] <- 5
	col_plot[output_nonclust[,col_plot_ind] == "sanguinarine"] <- 6
	col_plot[output_nonclust[,col_plot_ind] == "unknown"] <- 7
	col_plot[output_nonclust[,col_plot_ind] == "papaverine"] <- 8
	col_plot[output_nonclust[,col_plot_ind] == "papaverine_derivatives"] <- 8
	col_plot[output_nonclust[,col_plot_ind] == "reticuline_derivatives"] <- 4
	output_nonclust$col_plot <- col_plot
	
}


if (plotcol_choice == "enzyme_family"){
	col_plot_ind <- which (colnames(output_plot2) == plotcol_choice) #set the column to be used for colour plotting

	
	col_plot <- array(8,nrow(output_plot2))
	col_plot[output_plot2[,col_plot_ind] == "O-methyltransferase"] <- 1
	col_plot[output_plot2[,col_plot_ind] == "PLP decarboxylase"] <- 2
	col_plot[output_plot2[,col_plot_ind] == "O-demethylase"] <- 3
	col_plot[output_plot2[,col_plot_ind] == "PR10_MLP"] <- 4
	col_plot[output_plot2[,col_plot_ind] == "N-methyltransferase"] <- 5
	col_plot[output_plot2[,col_plot_ind] == "cytochrome P450"] <- 6
	col_plot[output_plot2[,col_plot_ind] == "aldo-keto reductase"] <- 7
	output_plot2$col_plot <- col_plot
	the_cols <- c("cyan","purple","red","green","pink","darkorange","blue","black") 

	col_plot_ind <- which (colnames(output_nonclust) == plotcol_choice) #set the column to be used for colour plotting
	
	col_plot <- array(8,nrow(output_nonclust))
	col_plot[output_nonclust[,col_plot_ind] == "O-methyltransferase"] <- 1
	col_plot[output_nonclust[,col_plot_ind] == "PLP decarboxylase"] <- 2
	col_plot[output_nonclust[,col_plot_ind] == "O-demethylase"] <- 3
	col_plot[output_nonclust[,col_plot_ind] == "PR10_MLP"] <- 4
	col_plot[output_nonclust[,col_plot_ind] == "N-methyltransferase"] <- 5
	col_plot[output_nonclust[,col_plot_ind] == "cytochrome P450"] <- 6
	col_plot[output_nonclust[,col_plot_ind] == "aldo-keto reductase"] <- 7
	output_nonclust$col_plot <- col_plot
	
}


if (plotcol_choice == "guo_comparison"){
	col_plot_ind <- which (colnames(output_plot2) == plotcol_choice) #set the column to be used for colour plotting

	
	col_plot <- array(2,nrow(output_plot2))
	col_plot[output_plot2[,col_plot_ind] == "yes"] <- 1
	col_plot[output_plot2[,col_plot_ind] == "no"] <- 2
	output_plot2$col_plot <- col_plot
	the_cols <- c("black","red") 

	col_plot_ind <- which (colnames(output_nonclust) == plotcol_choice) #set the column to be used for colour plotting
	
	col_plot <- array(2,nrow(output_nonclust))
	col_plot[output_nonclust[,col_plot_ind] == "yes"] <- 1
	col_plot[output_nonclust[,col_plot_ind] == "no"] <- 2
	output_nonclust$col_plot <- col_plot
	
}








plot (1,1,xlim = xlims,ylim = c (0,(length (length5)*ymult+1)),col = "white",xlab = "Physical position on chromosomal scaffolds (Mbp)", xaxt = "n",yaxt = "n",ylab ="", bty = "n")


x_axis_coord <- c(0,10^8,2*10^8,3*10^8) / chrom_mult
axis (1,x_axis_coord,labels = c(0,100,200,300))

length6 <- length5[order(as.numeric(names(length5)))]

new_ord <- c(1,11,3,4,5,6,7,8,9,10,2)
length6 <- length6[new_ord]
last_end <- 0  #if not, then set another counter

for (pp in 1:length (length6)){
	
	
	sub_scaf <- output_plot2[output_plot2[,toscaf] == names(length6[pp]),]
	ydisp <- ((length (length6)*ymult+1) - (pp*ymult))

	scafnam1 <- sapply(strsplit (sub_scaf$scaffold_name[1],split = "scaffold"),"[[",2)
	scafnam2 <- paste ("cScaf",(as.numeric (scafnam1)+1),sep = "")
	text ((max(length6)*-0.05),ydisp,scafnam2)


	sub_clusts <- unique (sub_scaf[,toplot])
	
		
	

	if ((length6[pp] / xlims[2]) > 0.25){  #check to see if the clusters are going to take up most of the real estate when plotted
		xdisp <- 0 #if so, then start them at 0
	} else {
		last_end <- 0  #if not, then set another counter
	}

	sub_nonclust <- output_nonclust[output_nonclust$scaffold_name == sub_scaf$scaffold_name[1],]

	sub_gene1 <- genes[genes$scaffold_name == sub_scaf$scaffold_name[1],]

	chrom_end <- sub_scaf$chrom_length[1] / chrom_mult
	arrows (0,ydisp,chrom_end,ydisp, length = 0, lwd = 10,col = "grey80") ##PLOT chrom

	ydisp_adj <- ydisp_offset

	last_gene_name_x <- 0
	last_gene_name_x2 <- 0

if (sum(sub_clusts < 0) == 0){


for (i in 1:length (sub_clusts)){

	sub1 <- sub_scaf[sub_scaf[,toplot] == sub_clusts[i],]

	sub_gene2 <- sub_gene1[sub_gene1[,4] > min(sub1$Low) & sub_gene1[,5] < max(sub1$High),]



	if ((length6[pp] / xlims[2]) <= 0.5){ #check to see if the clusters are going to take up most of the real estate when plotted

		mean1 <- (min(sub1$Low) + max (sub1$High)) / 2
		range1 <- max (sub1$High) - min(sub1$Low)

		new_xdisp <- (mean1 / chrom_mult) - (range1 / 2)
		
		if ((new_xdisp - extend_x) < 0){ #if it's going to be plotted with x < 0, then reset
			xdisp <- 0
		} else {
			xdisp <- new_xdisp
		}
		
		if ( (xdisp-extend_x) < (last_end + 10000) ){	#if the plotting is going to be too close, then set it to space of 10000
			xdisp <- (last_end + 10000)
		}
		
		
	}


	sub1_begin <- min (c(sub1[,3],sub1[,4]))
	sub1_end <- max (c(sub1[,3],sub1[,4]))
	sub1_length <- sub1_end - sub1_begin

	ydisp_clust <- ydisp + ydisp_adj


	arrows ((xdisp-extend_x),ydisp_clust,(sub1_begin/chrom_mult),ydisp, length = 0,col = "grey50", lty = 3) ##PLOT joining arrow1
	arrows ((sub1_end/chrom_mult),ydisp,(xdisp + sub1_length+ extend_x),ydisp_clust, length = 0,col = "grey50", lty = 3) ##PLOT joining arrow2

	arrows ((xdisp-extend_x),ydisp_clust,(xdisp + sub1_length+ extend_x),ydisp_clust, length = 0,lwd = 2) ##PLOT SCAFFOLD


	#plot the location of the cluster on the chrocomosome
	the_x <- c((sub1_end/chrom_mult),(sub1_end/chrom_mult),(sub1_begin/chrom_mult),(sub1_begin/chrom_mult))
	the_y <- c(ydisp + yclust_offset,ydisp - yclust_offset,ydisp - yclust_offset,ydisp + yclust_offset)
	polygon(the_x,the_y, col = "white", border = "black")


	last_end <- (xdisp + sub1_length+ extend_x) ##the end of the current scaffold..to make sure the next one is away from it
	
	

	for (j in 1:nrow(sub1)){
		bicolour <- c("BBE.1","BBE.2")
		
		if (sub1$path[j] %in% bicolour & plotcol_choice == "pathway_new"){
				
				both_names <- c(sapply(strsplit (sub1$pathway_new[j],split = "_"),"[[",1),sapply(strsplit (sub1$pathway_new[j],split = "_"),"[[",2))
	
				both_names [both_names == "noscapine"] <- "black"
				both_names [both_names == "sanguinarine"] <- "red"
				both_names [both_names == "papaverine"] <- rgb(0.75,0.75,0.25)

			the_x <- c((sub1$Low[j] - sub1_begin + xdisp),(sub1$Low[j] - sub1_begin + xdisp),(sub1$High[j] - sub1_begin + xdisp),(sub1$High[j] - sub1_begin + xdisp))
			the_y <- c((ydisp_clust),(ydisp_clust - yheight),(ydisp_clust - yheight),(ydisp_clust))
				polygon(the_x,the_y, col = both_names[1], border = both_names[1])

			the_x <- c((sub1$Low[j] - sub1_begin + xdisp),(sub1$Low[j] - sub1_begin + xdisp),(sub1$High[j] - sub1_begin + xdisp),(sub1$High[j] - sub1_begin + xdisp))
			the_y <- c((ydisp_clust + yheight),(ydisp_clust),(ydisp_clust),(ydisp_clust + yheight))

				polygon(the_x,the_y, col = both_names[2], border = both_names[2])

			the_y <- c((ydisp_clust + yheight),(ydisp_clust - yheight),(ydisp_clust - yheight),(ydisp_clust + yheight))

				
		} else {
		
			#GENE PLOTTER:
			the_x <- c((sub1$Low[j] - sub1_begin + xdisp),(sub1$Low[j] - sub1_begin + xdisp),(sub1$High[j] - sub1_begin + xdisp),(sub1$High[j] - sub1_begin + xdisp))
			the_y <- c((ydisp_clust + yheight),(ydisp_clust - yheight),(ydisp_clust - yheight),(ydisp_clust + yheight))

			polygon(the_x,the_y, col = the_cols[as.numeric (sub1$col_plot[j])], border = the_cols[as.numeric (sub1$col_plot[j])])
				
		}
				
	
			
		#GENE PLOTTER:
		the_x <- c((sub1$Low[j] - sub1_begin + xdisp),(sub1$Low[j] - sub1_begin + xdisp),(sub1$High[j] - sub1_begin + xdisp),(sub1$High[j] - sub1_begin + xdisp))
		the_y <- c((ydisp_clust + yheight),(ydisp_clust - yheight),(ydisp_clust - yheight),(ydisp_clust + yheight))

		polygon(the_x,the_y, col = the_cols[as.numeric (sub1$col_plot[j])], border = the_cols[as.numeric (sub1$col_plot[j])])
		
		#the_text <- sub1$New.name[j]
		the_text <- sub1$path[j]
		
		the_pos <- paste (sub1$Chromosome[j],sub1$Start[j],sep = "---")
		
		if(the_pos %in% pseudo$the_pos){
			the_text_col <- "grey50"
		} else {
			the_text_col <- "black"
		}

	
		
		if ((mean(the_x) - last_gene_name_x) < text_disp1 & (!(j == 1 & i == 1))){ #don't adjust the plotting distance for the first gene:
			text ((last_gene_name_x + (text_disp2)),(ydisp_clust + 0.2 + yheight),the_text,cex = text_cex,adj = c(0,0.5),srt = the_srt, col = the_text_col)
			last_gene_name_x <- (last_gene_name_x + (text_disp2))

			
		} else {		
			text (mean(the_x),(ydisp_clust + 0.2 + yheight),the_text,cex = text_cex,adj = c(0,0.5),srt = the_srt, col = the_text_col)
			last_gene_name_x <- mean(the_x)
		}
	}
	
	#NON-PATHWAY GENE PLOTTER:
	if (plot_nonpath == T){
		
	if (nrow(sub_gene2) > 1){
		
		for (j in 1:nrow(sub_gene2)){

					
			test_in1 <- sub_gene2[j,4] <= sub1$Low & sub_gene2[j,5] >= sub1$Low  #check if it's in the region of a pathway gene, if not, then plot
			test_in2 <- sub_gene2[j,5] <= sub1$High & sub_gene2[j,5] >= sub1$High  #check if it's in the region of a pathway gene, if not, then plot
			test_in3 <- sub_gene2[j,4] >= sub1$low & sub_gene2[j,4] <= sub1$High
			test_in4 <- sub_gene2[j,5] >= sub1$low & sub_gene2[j,5] <= sub1$High
			
		
			if (sum(test_in1) + sum(test_in2) + sum(test_in3) + sum (test_in4) == 0){
			
				the_x <- c((sub_gene2[j,4] - sub1_begin + xdisp),(sub_gene2[j,4] - sub1_begin + xdisp),(sub_gene2[j,5] - sub1_begin + xdisp),(sub_gene2[j,5] - sub1_begin + xdisp))
				the_y <- c((ydisp_clust + nonpath_size),(ydisp_clust - nonpath_size),(ydisp_clust - nonpath_size),(ydisp_clust + nonpath_size))

				polygon(the_x,the_y, col = "green", border = "green")
			}

		}
	}
	}
	
	#set next chromosome_plotting spot
if ((length6[pp] / xlims[2]) > 0.25){
	xdisp <- xdisp + sub1_length + 10000
} 


}
} else { ##if it's a chromosome with no clusters:
	sub_nonclust <- sub_scaf	
}


	if (plot_nonclust == T){
		for (nn in 1:nrow (sub_nonclust)){
		
			bicolour <- c("DBOX.1","DBOX.2","TNMT.1")
		
			if (sub_nonclust$path[nn] %in% bicolour & plotcol_choice == "pathway_new"){
				
				both_names <- c(sapply(strsplit (sub_nonclust$pathway_new[nn],split = "_"),"[[",1),sapply(strsplit (sub_nonclust$pathway_new[nn],split = "_"),"[[",2))
	
				both_names [both_names == "noscapine"] <- "black"
				both_names [both_names == "sanguinarine"] <- "red"
				both_names [both_names == "papaverine"] <- rgb(0.75,0.75,0.25)

				the_x <- c(sub_nonclust$Low[nn]/chrom_mult,sub_nonclust$Low[nn]/chrom_mult,(sub_nonclust$Low[nn]/chrom_mult)+1000,(sub_nonclust$Low[nn]/chrom_mult)+1000)
				the_y <- c(ydisp - yheight,ydisp, ydisp, ydisp - yheight)
				polygon(the_x,the_y, col = both_names[1], border = both_names[1])

				the_x <- c(sub_nonclust$Low[nn]/chrom_mult,sub_nonclust$Low[nn]/chrom_mult,(sub_nonclust$Low[nn]/chrom_mult)+1000,(sub_nonclust$Low[nn]/chrom_mult)+1000)
				the_y <- c(ydisp,ydisp + yheight, ydisp + yheight, ydisp)
				polygon(the_x,the_y, col = both_names[2], border = both_names[2])

				the_y <- c(ydisp - yheight,ydisp + yheight, ydisp + yheight, ydisp - yheight)

				
			} else {
		
				the_x <- c(sub_nonclust$Low[nn]/chrom_mult,sub_nonclust$Low[nn]/chrom_mult,(sub_nonclust$Low[nn]/chrom_mult)+1000,(sub_nonclust$Low[nn]/chrom_mult)+1000)
				the_y <- c(ydisp - yheight,ydisp + yheight, ydisp + yheight, ydisp - yheight)
				polygon(the_x,the_y, col = the_cols[as.numeric (sub_nonclust$col_plot[nn])], border = the_cols[as.numeric (sub_nonclust$col_plot[nn])])
				
			}
				
			#the_text <- sub_nonclust$New.name[nn]
			the_text <- sub_nonclust$path[nn]
	
			the_pos <- paste (sub_nonclust$Chromosome[j], sub_nonclust$Start[j],sep = "---")
		
			if(sum (the_pos %in% pseudo$the_pos) >= 1){
				the_text_col <- "grey50"
			} else {
				the_text_col <- "black"
			}
		


			names_left <- c("NCS.1","CNMT.1","6OMT.1","CYP80B1.2","194980059","188398896","144217104")
			names_right <- c("4OMT2.1","COR1.2","CYP80B1.1", "6OMT.2","197013213","255874288")
			

			names_up <- c ("DBOX.2","MLP-1.2","PR10-10.1")

			
			# if (sub_nonclust$New.name[nn] %in% names_left){
			 if (sub_nonclust$path[nn] %in% names_left){
				 text (((mean(the_x)-non_clust_offset) - 3000),(min (the_y)-0.5),the_text,cex = text_cex,pos = 2,srt = the_srt, col = the_text_col)				
			 } else if (sub_nonclust$path[nn] %in% names_right){
			 #} else if (sub_nonclust$New.name[nn] %in% names_right){
				 text (((mean(the_x)-non_clust_offset) + 3000),(min (the_y)-0.5),the_text,cex = text_cex,pos = 2,srt = the_srt, col = the_text_col)
			 } else {
			 	if (sub_nonclust$path[nn] %in% names_up){
			 	 	text ((mean(the_x)-non_clust_offset - 4000),(min (the_y)-0.8),the_text,cex = text_cex,srt = 0)
			 	} else {
				 text ((mean(the_x)-non_clust_offset),(min (the_y)-0.5),the_text,cex = text_cex,pos = 2,srt = the_srt, col = the_text_col)	
			 	}
			 }
			
		
		}	
	}




}

arrows ((xlims[2]*0.75),13,(xlims[2]*0.75 + 100000),13,length = 0.07, angle = 90, code = 3)
text ((xlims[2]*0.75 + 50000),15,labels ="Scale for enlarged regions = 100 kbp", cex = 0.8)








#####
##### MAKE CLUSTER FILE
#####
write_cluster <- F
if(write_cluster == T){

to_cluster <- which (colnames (output_plot2) == "clust0.5")

output_plot3 <- output_plot2[output_plot2[,to_cluster] > 0,]

the_low <- tapply (output_plot3$Low,output_plot3[,to_cluster],min)
the_high <- tapply (output_plot3$High,output_plot3[,to_cluster],max)
the_chrom <- tapply (output_plot3$Chromosome,output_plot3[,to_cluster],unique)

output <- cbind (the_chrom,the_low,the_high,(the_low - 5000),(the_high + 5000))


colnames (output) <- c("chrom", "start", "end", "start_5k", "end_5k")
write.table (output,"poppy_clusters_500kb_5kwindow_new109.txt",row.names = F, col.names = T, sep = "\t",quote = F)
}
