
##Written by Sam Yeaman
##Used to generate the tables showing the number of genes clustered at different pathway distances, both with- and without- tandem duplicates. Table S4, S5, and Figure 3A
##The "FINE" refers to whether a large number of clustering distances was used, as in the figure 3A or a smaller number, as in the incremental test.




setwd("~/Dropbox/desktop/for_sukyi/")


#output <- read.table ("pathway_genes_hic_inversion_clustered.txt", T, sep = "\t")
output <- read.table ("pathway_genes_hic_inversion_clustered_FINE.txt", T, sep = "\t")


#output <- read.table ("pathway_genes_hic_inversion_clustered_TANDEM_FINE.txt", T, sep = "\t")



ind1 <- grep ("clust",colnames(output))

nam1 <- sapply (strsplit (colnames (output)[ind1],split = "clust"), "[[",2)

uniq1 <- unique (output$Chromosome)
sep1 <- sapply (strsplit (as.character (uniq1),split = "_length_"),"[[",2)
gsize <- sum (as.numeric (sep1))

colSums (output[,ind1] > 0)

results <- array (NA,c(length(ind1),6))

for (bb in 1:length (ind1)){

	sub1 <- output[output[,ind1[bb]] > 0,]

	results[bb,1] <- as.numeric (nam1 [bb])
	results[bb,2] <- nrow (sub1) ## number of clustered genes
	results[bb,3] <- nrow (sub1) / nrow (output) ## percentage of genes clustered
	results[bb,4] <- length (unique (sub1[,ind1[bb]])) ## number of clusters
	
	the_clust <- unique (sub1[,ind1[bb]])
	
	temp1 <- 0
	
	for (cc in 1:length (the_clust)){
		
		sub2 <- sub1[sub1[,ind1[bb]] == the_clust[cc],]
		
		temp1 <- temp1 + (max (sub2$High) - min (sub2$Low))
		
	}
	results[bb,5] <- temp1  ## size of the genome in clusters
	results[bb,6] <- temp1 / gsize ## percentage of genome in clusters
	

}

#outputs for Table S4
colnames (results) <- c("cluster_size","number_genes","percent_genes","number_clust","size_clust","percentage_clust")

#write.table (results,"table_cluster_size_hic_inversions.txt",row.names = F, col.names = T, quote = F, sep = "\t")
write.table (results,"table_cluster_size_hic_inversions_FINE.txt",row.names = F, col.names = T, quote = F, sep = "\t")

#write.table (results,"table_cluster_size_hic_inversions_nontandem_FINE.txt",row.names = F, col.names = T, quote = F, sep = "\t")


#FIGURE 3a
results <- read.table ("table_cluster_size_hic_inversions_FINE.txt",T)
plot (log10(results$cluster_size),results$number_genes, type = "o", cex = 0.5,xlab = "Maximum clustering distance (Mbp)",ylab = "Number of genes clustered",xaxt = "n", col = "white", cex.axis = 1.5, cex.lab = 1.5)

arrows (1,-1000,1,1000,col = "purple",lwd = 2) ## upper bound for signficance by global test
arrows (log10(0.5),-1000,log10(0.5),1000,col = "red",lwd = 2) ## upper bound for signficance by incremental test

arrows (log10(0.2),20,log10(0.1),20,col = "red", length = 0.1)
arrows (0.5,20,0.2,20,col = "purple", length = 0.1)

text (log10(0.29),20,"incremental",col = "red",srt = 90, cex = 1.5)
text (0.75,20,"global",col = "purple",srt = 90, cex = 1.5)


points (log10(results$cluster_size),results$number_genes, type = "o", cex = 0.5)
axis (1,at = c (-3,-2,-1,0,1,2),c(0.001,0.01,0.1,1,10,100), cex.axis = 1.5)






